pub struct Solver<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Solver<'a>
impl<'a> Solver<'a>
Sourcepub fn new(
db: &'a CompiledDatabase,
goals: Vec<Term>,
query_vars: FnvHashMap<String, VarId>,
) -> Self
pub fn new( db: &'a CompiledDatabase, goals: Vec<Term>, query_vars: FnvHashMap<String, VarId>, ) -> Self
Create a new solver for a query against a compiled database.
pub fn with_limit(self, limit: usize) -> Self
pub fn with_max_depth(self, max_depth: usize) -> Self
Sourcepub fn interner(&self) -> &StringInterner
pub fn interner(&self) -> &StringInterner
Get the solver’s interner (includes any runtime-created atoms).
Sourcepub fn next(&mut self) -> SolveResult
pub fn next(&mut self) -> SolveResult
Get the next solution (or failure/error).
Sourcepub fn all_solutions_with_interner(
self,
) -> Result<(Vec<Solution>, StringInterner), String>
pub fn all_solutions_with_interner( self, ) -> Result<(Vec<Solution>, StringInterner), String>
Enumerate all solutions, returning the interner for term display.